==> servicemix-wsn2005-3.3.0.5-fuse-sources.jar: org/apache/servicemix/wsn/jaxws/PublisherRegistrationManagerServiceService.java <==

package org.apache.servicemix.wsn.jaxws;

import java.net.MalformedURLException;
import java.net.URL;
import java.util.HashMap;
import java.util.Map;
import javax.xml.namespace.QName;
import javax.xml.ws.Service;
import javax.xml.ws.WebEndpoint;
import javax.xml.ws.WebServiceClient;

@WebServiceClient(targetNamespace = "http://servicemix.apache.org/wsn/jaxws", name = "PublisherRegistrationManagerService", wsdlLocation = "file:/home/bsnyder/src/iona/servicemix/tags/servicemix-3.3.0.5-fuse/deployables/serviceengines/servicemix-wsn2005/src/main/resources/org/apache/servicemix/wsn/wsn.wsdl")
public class PublisherRegistrationManagerServiceService
    extends Service
{

    private static Map ports = new HashMap();
    public static Class PublisherRegistrationManager = org.apache.servicemix.wsn.jaxws.PublisherRegistrationManager.class;

    static {
        ports.put(new QName("http://servicemix.apache.org/wsn/jaxws", "PublisherRegistrationManagerServiceLocalPort"), PublisherRegistrationManager);
        ports.put(new QName("http://servicemix.apache.org/wsn/jaxws", "JBI"), PublisherRegistrationManager);
    }

    public PublisherRegistrationManagerServiceService()
        throws MalformedURLException
    {
        super(new URL("file:/home/bsnyder/src/iona/servicemix/tags/servicemix-3.3.0.5-fuse/deployables/serviceengines/servicemix-wsn2005/src/main/resources/org/apache/servicemix/wsn/wsn.wsdl"), new QName("http://servicemix.apache.org/wsn/jaxws", "PublisherRegistrationManagerService"));
    }

    public static Map getPortClassMap() {
        return ports;
    }

    @WebEndpoint(name = "PublisherRegistrationManagerServiceLocalPort")
    public org.apache.servicemix.wsn.jaxws.PublisherRegistrationManager getPublisherRegistrationManagerServiceLocalPort() {
        return ((org.apache.servicemix.wsn.jaxws.PublisherRegistrationManager)(this).getPort(new QName("http://servicemix.apache.org/wsn/jaxws", "PublisherRegistrationManagerServiceLocalPort"), PublisherRegistrationManager));
    }

    @WebEndpoint(name = "JBI")
    public org.apache.servicemix.wsn.jaxws.PublisherRegistrationManager getJBI() {
        return ((org.apache.servicemix.wsn.jaxws.PublisherRegistrationManager)(this).getPort(new QName("http://servicemix.apache.org/wsn/jaxws", "JBI"), PublisherRegistrationManager));
    }

}

==> servicemix-wsn2005-3.3.0.8-fuse-sources.jar: org/apache/servicemix/wsn/jaxws/PublisherRegistrationManagerServiceService.java <==

package org.apache.servicemix.wsn.jaxws;

import java.net.MalformedURLException;
import java.net.URL;
import java.util.HashMap;
import java.util.Map;
import javax.xml.namespace.QName;
import javax.xml.ws.Service;
import javax.xml.ws.WebEndpoint;
import javax.xml.ws.WebServiceClient;

@WebServiceClient(targetNamespace = "http://servicemix.apache.org/wsn/jaxws", name = "PublisherRegistrationManagerService", wsdlLocation = "file:/x1/janstey/servicemix-3.3.0-fuse/deployables/serviceengines/servicemix-wsn2005/src/main/resources/org/apache/servicemix/wsn/wsn.wsdl")
public class PublisherRegistrationManagerServiceService
    extends Service
{

    private static Map ports = new HashMap();
    public static Class PublisherRegistrationManager = org.apache.servicemix.wsn.jaxws.PublisherRegistrationManager.class;

    static {
        ports.put(new QName("http://servicemix.apache.org/wsn/jaxws", "PublisherRegistrationManagerServiceLocalPort"), PublisherRegistrationManager);
        ports.put(new QName("http://servicemix.apache.org/wsn/jaxws", "JBI"), PublisherRegistrationManager);
    }

    public PublisherRegistrationManagerServiceService()
        throws MalformedURLException
    {
        super(new URL("file:/x1/janstey/servicemix-3.3.0-fuse/deployables/serviceengines/servicemix-wsn2005/src/main/resources/org/apache/servicemix/wsn/wsn.wsdl"), new QName("http://servicemix.apache.org/wsn/jaxws", "PublisherRegistrationManagerService"));
    }

    public static Map getPortClassMap() {
        return ports;
    }

    @WebEndpoint(name = "PublisherRegistrationManagerServiceLocalPort")
    public org.apache.servicemix.wsn.jaxws.PublisherRegistrationManager getPublisherRegistrationManagerServiceLocalPort() {
        return ((org.apache.servicemix.wsn.jaxws.PublisherRegistrationManager)(this).getPort(new QName("http://servicemix.apache.org/wsn/jaxws", "PublisherRegistrationManagerServiceLocalPort"), PublisherRegistrationManager));
    }

    @WebEndpoint(name = "JBI")
    public org.apache.servicemix.wsn.jaxws.PublisherRegistrationManager getJBI() {
        return ((org.apache.servicemix.wsn.jaxws.PublisherRegistrationManager)(this).getPort(new QName("http://servicemix.apache.org/wsn/jaxws", "JBI"), PublisherRegistrationManager));
    }

}
